@@ -51,7 +51,9 @@ def install(
     logger.info("Installing scvi-tools.")
 
     if not unfixed:
-        _run_command("pip install torchtext==0.12.0 --no-deps")
+        # temporary as pytorch 1.11 not in google colab
+        # TODO: remove once pytorch 1.11 in colab with gpu
+        _run_command("pip install pyro-ppl==1.8.0")
         _run_command("pip install pynndescent")
         # caching issues in colab causing pynndescent import to fail
         success = False
@@ -68,16 +70,12 @@ def install(
         if version is not None:
             command += f"=={version}"
     else:
-        _run_command("pip install --quiet --upgrade jsonschema")
         repo = (
             f"https://github.com/scverse/scvi-tools@{branch}#egg=scvi-tools[tutorials]"
         )
         command = f"pip install --quiet git+{repo}"
     _run_command(command)
 
-    if not unfixed:
-        _run_command("pip install --upgrade rich==10.0.0")
-
     logger.info("Install successful. Testing import.")
 
     import scvi  # noqa: F401
